
(*-------------------------------------------------------------------------*)
(* file             : h_filter.mod                                         *)
(* description      : implementation of the 16bits high pass filter module *)
(* language         : GPM Modula-2                                         *)
(* organization     : -                                                    *)
(* autor            : Julian Miglio                                        *)
(* issue date       : July 09 2003                                         *)
(* version.release  : 1.1                                                  *)
(* notes            : This implementation uses only integer types, that    *)
(*                    raises the problem of the accuracy of the integer    *)
(*                    division. To avoid this problem it is necessary      *)
(*                    to multiply the input signal and divide the output   *)
(*                    signal for a constant (Gain_K) greater than the cut  *)
(*                    constant (Cut_K). It is possible to improve the      *)
(*                    performance using the 'shift' operation instead of   *)
(*                    multiplication and division.                         *)
(*-------------------------------------------------------------------------*)

IMPLEMENTATION MODULE H_Filter;

FROM Types  IMPORT Int16, Int32;
FROM SYSTEM IMPORT CAST;

CONST

   Gain_K = 010000H;

VAR

   Cc          : Int32;
   Cut_K_Local : CARDINAL;

   PROCEDURE Init( Cut_K : CARDINAL );
   BEGIN

      Cut_K_Local := Cut_K;      
      Cc := 0;      

   END Init;

   PROCEDURE Process_Signal( 
                In_Signal      : Int16;
                VAR Out_Signal : Int16 );

   VAR

      L_In  : Int32;
      L_Out : Int32;

   BEGIN

      L_In := CAST( Int32, In_Signal ) * Gain_K;
      Cc := Cc + ( L_In - Cc ) / CAST( Int32, Cut_K_Local );
      L_Out := L_In - Cc;
      Out_Signal := CAST( Int16, L_Out / Gain_K );

   END Process_Signal;                             
                   
END H_Filter.

                   
                   